@@ -1,5 +1,5 @@
 package App::CharmKit::Role::Init;
-$App::CharmKit::Role::Init::VERSION = '1.0.2';
+$App::CharmKit::Role::Init::VERSION = '1.0.5';
 # ABSTRACT: Initialization of new charms
 
 use strict;
@@ -16,9 +16,6 @@ sub init {
     my ($self, $path, $project) = @_;
     $path->child('hooks')->mkpath     or die $!;
     $path->child('tests')->mkpath     or die $!;
-    $path->child('src/hooks')->mkpath or die $!;
-    $path->child('src/tests')->mkpath or die $!;
-    $path->child('src/unittests')->mkpath or die $!;
 
     # .gitignore
     (   my $gitignore = qq{
@@ -81,7 +78,7 @@ perltidy.LOG
 done_testing;
 }
     );
-    $path->child('src/tests/01-deploy.test')->spew_utf8($basic_test);
+    $path->child('tests/01-deploy.test')->spew_utf8($basic_test);
 
     # charmkit.json
     my $json          = JSON::PP->new->utf8->pretty;
@@ -238,7 +235,7 @@ App::CharmKit::Role::Init - Initialization of new charms
 
 =head1 VERSION
 
-version 1.0.2
+version 1.0.5
 
 =head1 METHODS
 
